@@ -1,11 +1,9 @@
 # -*- encoding=utf8 -*-
 import sys
-sys.path.append('.')
-
 import datetime as dt, time, re, calendar, sys
-from utils import get_strdate_format
-from wull import wull, iswull, WULL
-from datetime import datetime
+from .utils import get_strdate_format
+from .wull import wull, iswull, WULL
+from .datetime import datetime
 
 if sys.version_info.major >=3 and sys.version_info.minor>=8:
     clocktime = time.perf_counter
